﻿using System;
using System.Configuration;
using System.IO;
using System.Text.RegularExpressions;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Shapes;
using ThinkGeo.MapSuite.WebForms;

namespace WebApplication1
{
    public partial class Index : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                // source
                string rootPath = Path.Combine(MapPath("~"), ConfigurationManager.AppSettings["RootDirectory"]);
                
                Map1.MapUnit = GeographyUnit.Meter;
                

                // ThinkGeoCloudMapsOverlay

                //var cloudMapsOverlay = new ThinkGeoCloudMapsOverlay();
                //cloudMapsOverlay.WrapDateline = WrapDatelineMode.WrapDateline;
                //Map1.CustomOverlays.Add(cloudMapsOverlay);

                //Map1.ZoomLevelSet = ThinkGeoCloudMapsOverlay.GetZoomLevelSet();
                //Map1.CurrentExtent = new RectangleShape(-16697924, 9349764, -10018754, 1804723);

                // heatOverlay                
                InMemoryFeatureLayer imfl = new InMemoryFeatureLayer();

                string csvPath = Path.Combine(rootPath, "sigwx_cat_06.csv");
                using (StreamReader sr = new StreamReader(csvPath))
                {

                    while (!sr.EndOfStream)
                    {
                        string line = sr.ReadLine();
                        string[] pars = line.Split(',');
                        double[] coords = Str2PtAsIs(pars[0]);
                        Feature newfeature = new Feature(coords[0], coords[1]);
                        
                        newfeature.ColumnValues.Add("CONFIRMED", pars[4]);
                        imfl.InternalFeatures.Add(newfeature);
                    }
                }

                imfl.Open();

                HeatStyle HeatStyle = new HeatStyle()
                {
                    PointRadius = 100,
                    PointRadiusUnit = DistanceUnit.Kilometer,
                    Alpha = 255,
                    PointIntensity = 10,
                    IntensityColumnName = "CONFIRMED",
                    IntensityRangeStart = 1,
                    IntensityRangeEnd = 20
                };

                HeatLayer heat = new HeatLayer(imfl.FeatureSource);
                heat.HeatStyle = HeatStyle;
                heat.Open();


                var heatOverlay = new LayerOverlay("Heat");
                heatOverlay.Layers.Add("Heat", heat);

                Map1.CustomOverlays.Add(heatOverlay);

                Map1.CurrentExtent = new RectangleShape(-100, 50, 100, -50);                
            }
        }

        public double[] Str2PtAsIs(string Coords)
        {
            string sign, adeg, mins, lat = "", lon = "";

            if ((IsNumeric(Coords.Substring(1, 4))) && (IsNumeric(Coords.Substring(6, 5))))
            {
                //Sign comes from degree 
                sign = (Coords.Substring(0, 1) == "N" ? "" : "-");        // If 7th position is N then +value else -value.
                adeg = (Coords.Substring(1, 2));
                mins = (Coords.Substring(3, 2));
                lat = sign + adeg + "." + mins;
                sign = (Coords.Substring(5, 1) == "E" ? "" : "-");
                adeg = (Coords.Substring(6, 3));
                mins = (Coords.Substring(9, 2));
                lon = sign + adeg + "." + mins;
            }
            else if ((IsNumeric(Coords.Substring(2, 3))) && (IsNumeric(Coords.Substring(6, 5))))
            {
                sign = (Coords.Substring(0, 2) == "EQ" ? "" : "");
                adeg = (Coords.Substring(2, 2));
                mins = (Coords.Substring(4, 1));
                lat = sign + adeg + "." + mins;
                sign = (Coords.Substring(5, 1) == "E" ? "" : "-");        // If 15th position is E then + else -.
                adeg = (Coords.Substring(6, 3));
                mins = (Coords.Substring(9, 2));
                lon = sign + adeg + "." + mins;
            }

            return new double[] { Convert.ToDouble(lon), Convert.ToDouble(lat) };
        }

        private bool IsNumeric(string strNum)
        {
            Regex NotIntPattern = new Regex("[^0-9-]");
            Regex IntPattern = new Regex("^-[0-9]+$|^[0-9]+$");
            return !NotIntPattern.IsMatch(strNum) && IntPattern.IsMatch(strNum);
        }
    }
}